@@ -8,15 +8,14 @@
 
 /* these includes are needed for KDE support */
 #include <KLocalizedString>
-#include <KMessageBox>
 
 /* these includes are needed for Qt support */
 #include <QApplication>
 #include <QGridLayout>
 #include <QIntValidator>
-#include <QLayout>
 #include <QLineEdit>
 #include <QPushButton>
+#include <QRandomGenerator>
 
 #ifdef DEBUG
 #include <QDebug>
@@ -185,7 +184,7 @@ void ExercisePercentage::createTask()
 {
     // the tasks are hardcoded here; there are some algorithms to convert
     // rational numbers to fractions, but it is not worth the effort here
-    switch (int ((double(qrand()) / RAND_MAX) * 19)) {
+    switch (QRandomGenerator::global()->bounded(19)) {
     case  0 :
         //m_number = QLocale().toString(0.5, 'f', 1);
         m_numberPercentage = QStringLiteral("75");
