@@ -28,7 +28,7 @@ public:
     explicit RatioWidget(QWidget * parent = nullptr, const Ratio &para_ratio = Ratio());
 
     /** destructor */
-    ~RatioWidget();
+    ~RatioWidget() override;
 
     /** set the task to be displayed */
     void setRatio(const Ratio &para_ratio);
@@ -44,7 +44,7 @@ private:
     bool m_questionMixed;
 
     /** overriding the paint event of FractionBaseWidget */
-    void paintEvent(QPaintEvent*) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent*) override;
 };
 
 #endif
